@@ -74,6 +74,16 @@ $app->registerRoutes($this,
 			'url' => '/api/accounts/{accountId}/folders/{folderId}/messages/{id}/move',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'avatars#url',
+			'url' => '/api/avatars/url/{email}',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'avatars#image',
+			'url' => '/api/avatars/image/{email}',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'proxy#redirect',
 			'url' => '/redirect',
