@@ -16,23 +16,25 @@ define(function(require) {
 
 	var channelNames = [
 		'account',
+		'aliases',
+		'attachment',
 		'folder',
 		'dav',
+		'keyboard',
 		'message',
 		'navigation',
 		'notification',
 		'state',
-		'ui',
-		'keyboard',
-		'aliases'
+		'sync',
+		'ui'
 	];
 
 	var channels = {};
 	_.each(channelNames, function(channelName) {
 		channels[channelName] = Radio.channel(channelName);
-		Radio.tuneIn(channelName);
+		// Uncomment the following line for debugging
+		// Radio.tuneIn(channelName);
 	});
 
 	return channels;
 });
-
