@@ -2,10 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Correu electrónic",
+    "Loading accounts" : "S'està carregant",
     "Error while loading the accounts." : "Error al carregar els comptes.",
     "Error while loading the selected account." : "Error al carregar el compte sel·leccionat.",
     "Can not load this folder." : "No s'ha pogut carregar aquesta carpeta.",
-    "Loading {folder}" : "Carregant {folder}",
     "Searching for {query}" : "Buscant per {query}",
     "Error while deleting message." : "Error en esborrar el missatge.",
     "Forwarded message" : "Missatge respost",
@@ -30,10 +30,12 @@ OC.L10N.register(
     "Unable to load the desired message" : "No s'ha pogut carregar el missatge desitjat",
     "There was a problem loading the message" : "Hi ha un problema al carregar el missatge",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "Nextcloud Mail" : "Nextcloud correo",
     "Show all folders" : "Mostra totes les carpetes",
     "Collapse folders" : "Redueix les carpetes",
     "Error while deleting account." : "Error al borrar el compte",
     "Choose a file to add as attachment" : "Escull un fitxer per adjuntar al correu",
+    "An error occurred while uploading {fname}" : "S'ha produït un error",
     "Reply" : "Respon",
     "Send" : "Envia",
     "Sending …" : "Enviant...",
@@ -46,6 +48,7 @@ OC.L10N.register(
     "Error while importing the calendar event" : "Error al importar l'esdeveniment de calendari",
     "Error while downloading calendar event" : "Error al carregar l'esdeveniment de calendari",
     "Error while loading messages." : "Error al carregar els missatges",
+    "Error while refreshing messages." : "Error al carregar els missatges",
     "Setting up your account" : "Configurant el teu compte",
     "Inbox" : "Safata d'Entrada",
     "Sent" : "Enviat",
@@ -55,8 +58,8 @@ OC.L10N.register(
     "Junk" : "Brossa",
     "All" : "Tots",
     "Favorites" : "Preferits",
-    "Creating account failed: " : "La creació del compte ha fallat:",
     "Auto detect failed. Please use manual mode." : "Detecció automatica fallida. Siusplau, utilitzi el mode manual.",
+    "Creating account failed: " : "La creació del compte ha fallat:",
     "Delete permanently" : "Esborra permanentment",
     "& others" : "& altres",
     "Error loading message" : "Error al carregar el missatge",
@@ -77,6 +80,7 @@ OC.L10N.register(
     "Save" : "Desa",
     "Keyboard shortcuts" : "Dreceres de teclat",
     "Speed up your Mail experience with these quick shortcuts." : "Accelera el teu us de Mail amb aquestes dreceres de teclat.",
+    "Compose new message" : "Nou missatge",
     "Newer message" : "Missatges més nous",
     "Older message" : "Missatges més vells",
     "Toggle star" : "Commuta l'estrella",
@@ -113,6 +117,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "S'han bloquejat les imatges per protegir la teva privacitat.",
     "Show images from this sender" : "Mostra imatges d'aquest remitent",
     "Forward" : "Respondre",
+    "No messages in this folder!" : "No hi ha missatges en aquesta carpeta!",
     "Import into calendar" : "Importar al calendari",
     "Download attachment" : "Descarrega l'adjunt",
     "Save to Files" : "Desa els fitxers"
