@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "E-Mail",
-    "Loading accounts …" : "Lade Konten...",
+    "Loading accounts" : "Lade Konten",
     "Error while loading the accounts." : "Fehler beim Laden der Konten.",
     "Error while loading the selected account." : "Fehler beim Laden des ausgewählten Kontos.",
     "Can not load this folder." : "Dieser Ordner kann nicht geladen werden.",
-    "Loading {folder}" : "Lade {folder}",
     "Searching for {query}" : "Suche nach {query}",
     "Error while deleting message." : "Fehler beim Löschen der Nachricht.",
     "Forwarded message" : "Weitergeleitete Nachricht",
@@ -37,7 +36,7 @@ OC.L10N.register(
     "Collapse folders" : "Ordner einklappen",
     "Error while deleting account." : "Fehler beim Löschen des Kontos.",
     "Choose a file to add as attachment" : "Wählen Sie eine Datei, die als Anhang angefügt werden soll",
-    "An error occurred while uploading {fname}" : "Fehler beim Hochladen von {fname} aufgetreten",
+    "An error occurred while uploading {fname}" : "Fehler aufgetreten beim Hochladen von {fname}",
     "Reply" : "Antworten",
     "Send" : "Senden",
     "Sending …" : "Sende…",
@@ -60,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Spam",
     "All" : "Alle",
     "Favorites" : "Favoriten",
-    "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
     "Auto detect failed. Please use manual mode." : "Automatische Erkennung fehlgeschlagen. Bitte nutzen Sie den manuellen Modus.",
+    "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
     "Delete permanently" : "Endgültig löschen",
     "& others" : "& weitere",
     "Error loading message" : "Fehler beim Laden der Nachricht",
@@ -119,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Die Bilder wurden blockiert um Ihre Privatsphäre zu schützen.",
     "Show images from this sender" : "Bilder dieses Absenders anzeigen",
     "Forward" : "Weiterleiten",
-    "Add attachment" : "Anhang hinzufügen",
-    "Add from Files" : "Anhang hinzufügen",
+    "No messages in this folder!" : "Keine Nachrichten in diesem Ordner",
+    "Upload attachment" : "Anhang hochladen",
+    "Add attachment from Files" : "Anhang von \"Dateien\" hinzufügen",
     "Import into calendar" : "In Kalender importieren",
     "Download attachment" : "Anhang herunterladen",
     "Save to Files" : "Unter Dateien speichern"
