@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Correo electrónico",
-    "Loading accounts …" : "Cargando cuentas ...",
+    "Loading accounts" : "Cargando cuentas",
     "Error while loading the accounts." : "Error al cargar las cuentas.",
     "Error while loading the selected account." : "Error al cargar la cuenta seleccionada.",
     "Can not load this folder." : "No se puede cargar esta carpeta.",
-    "Loading {folder}" : "Cargando {folder}",
     "Searching for {query}" : "Buscando por (consulta)",
     "Error while deleting message." : "Error al eliminar el mensaje.",
     "Forwarded message" : "Mensaje reenviado",
@@ -60,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Basura",
     "All" : "Todos",
     "Favorites" : "Favoritos",
-    "Creating account failed: " : "No se pudo crear la cuenta:",
     "Auto detect failed. Please use manual mode." : "La autodetección falló. Use el modo manual.",
+    "Creating account failed: " : "No se pudo crear la cuenta:",
     "Delete permanently" : "Eliminar permanentemente",
     "& others" : "y otros",
     "Error loading message" : "Error al cargar el mensaje",
@@ -119,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad.",
     "Show images from this sender" : "Mostrar imágenes de este remitente",
     "Forward" : "Reenviar",
-    "Add attachment" : "Añadir adjunto",
-    "Add from Files" : "Añadir desde Archivos",
+    "No messages in this folder!" : "¡No hay mensajes en esta carpeta!",
+    "Upload attachment" : "Subir adjunto",
+    "Add attachment from Files" : "Añadir adjunto desde Archivos",
     "Import into calendar" : "Importar dentro del calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar en Archivos"
