@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Mail",
-    "Loading accounts …" : "Chargement des comptes …",
+    "Loading accounts" : "Chargement des comptes",
     "Error while loading the accounts." : "Erreur lors du chargement des comptes.",
     "Error while loading the selected account." : "Erreur lors du chargement du compte sélectionné.",
     "Can not load this folder." : "Impossible de charger ce dossier.",
-    "Loading {folder}" : "Chargement de {folder}",
     "Searching for {query}" : "Recherche pour {query}",
     "Error while deleting message." : "Erreur lors de la suppression du message.",
     "Forwarded message" : "Message transféré",
@@ -60,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Indésirables",
     "All" : "Tous",
     "Favorites" : "Favoris",
-    "Creating account failed: " : "La création du compte a échoué : ",
     "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
+    "Creating account failed: " : "La création du compte a échoué : ",
     "Delete permanently" : "Supprimer définitivement",
     "& others" : "et d'autres",
     "Error loading message" : "Erreur lors du chargement du message",
@@ -119,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
     "Show images from this sender" : "Voir les images de cet expéditeur",
     "Forward" : "Faire suivre",
-    "Add attachment" : "Ajouter une pièce-jointe",
-    "Add from Files" : "Ajouter depuis Fichiers",
+    "No messages in this folder!" : "Aucun message dans ce dossier",
+    "Upload attachment" : "Téléverser les pièces jointes",
+    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
     "Import into calendar" : "Importer dans le calendrier",
     "Download attachment" : "Télécharger les pièces jointes",
     "Save to Files" : "Enregistrer dans Fichiers"
