@@ -2,10 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Póstur",
+    "Loading accounts" : "Hleð inn notendaaðgöngum",
     "Error while loading the accounts." : "Gat ekki lesið inn notandaaðganga..",
     "Error while loading the selected account." : "Villa við að lesa inn valinn notandaaðgang.",
     "Can not load this folder." : "Gat ekki að hlaðið inn möppunni.",
-    "Loading {folder}" : "Hleð inn {folder}",
     "Searching for {query}" : "Leita að {query}",
     "Error while deleting message." : "Villa kom upp við að eyða skilaboðum.",
     "Forwarded message" : "Áframsent skeyti",
@@ -59,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Ruslpóstur",
     "All" : "Allt",
     "Favorites" : "Eftirlæti",
-    "Creating account failed: " : "Mistókst að búa til notandaaðgang: ",
     "Auto detect failed. Please use manual mode." : "Mistókst að finna sjálkrafa. Notaðu handvirku leiðina.",
+    "Creating account failed: " : "Mistókst að búa til notandaaðgang: ",
     "Delete permanently" : "Eyða varanlega",
     "& others" : "og aðrir",
     "Error loading message" : "Villa við hleðslu á skilaboðum",
@@ -118,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
     "Show images from this sender" : "Birta myndir frá þessum sendanda",
     "Forward" : "Áframsenda",
-    "Add attachment" : "Bæta við viðhengi",
-    "Add from Files" : "Bæta við úr skrám",
+    "No messages in this folder!" : "Engin skilaboð í þessari möppu!",
+    "Upload attachment" : "Senda inn viðhengi",
+    "Add attachment from Files" : "Bæta við viðhengi úr skrám",
     "Import into calendar" : "Flytja inn dagatal",
     "Download attachment" : "Sækja viðhengi",
     "Save to Files" : "Vista í skrár"
