@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Posta",
-    "Loading accounts …" : "Caricamento account in corso...",
+    "Loading accounts" : "Caricamento account",
     "Error while loading the accounts." : "Errore durante il caricamento degli account.",
     "Error while loading the selected account." : "Errore durante il caricamento dell'account selezionato.",
     "Can not load this folder." : "Impossibile caricare questa cartella.",
-    "Loading {folder}" : "Caricamento {folder}",
     "Searching for {query}" : "Ricerca di {query}",
     "Error while deleting message." : "Errore durante l'eliminazione del messaggio.",
     "Forwarded message" : "Messaggio inoltrato",
@@ -60,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Posta indesiderata",
     "All" : "Tutti",
     "Favorites" : "Preferiti",
-    "Creating account failed: " : "Creazione account non riuscita:",
     "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
+    "Creating account failed: " : "Creazione account non riuscita:",
     "Delete permanently" : "Elimina definitivamente",
     "& others" : "e altri",
     "Error loading message" : "Errore durante il caricamento del messaggio",
@@ -119,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Le immagini sono state bloccate per proteggere la tua riservatezza.",
     "Show images from this sender" : "Mostra immagini da questo mittente",
     "Forward" : "Inoltra",
-    "Add attachment" : "Aggiungi allegato",
-    "Add from Files" : "Aggiungi da File",
+    "No messages in this folder!" : "Nessun messaggio in questa cartella",
+    "Upload attachment" : "Carica allegato",
+    "Add attachment from Files" : "Aggiungi allegato da File",
     "Import into calendar" : "Importa nel calendario",
     "Download attachment" : "Scarica allegato",
     "Save to Files" : "Salva in File"
