@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "E-post",
-    "Loading accounts …" : "Laster kontoer…",
+    "Loading accounts" : "Laster kontoer",
     "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
     "Error while loading the selected account." : "Feil ved lasting av den valgte kontoen.",
     "Can not load this folder." : "Kan ikke laste denne mappen.",
-    "Loading {folder}" : "Laster {folder}",
     "Searching for {query}" : "Søker etter {query}",
     "Error while deleting message." : "Feil ved sletting av melding.",
     "Forwarded message" : "Videresendt melding",
@@ -60,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Søppel",
     "All" : "Alle",
     "Favorites" : "Favoritter",
-    "Creating account failed: " : "Oppretting av konto mislyktes:",
     "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
+    "Creating account failed: " : "Oppretting av konto mislyktes:",
     "Delete permanently" : "Slett for godt",
     "& others" : "og andre",
     "Error loading message" : "Feil ved innlasting av melding",
@@ -119,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
     "Show images from this sender" : "Vis bilder fra denne avsenderen",
     "Forward" : "Videresend",
-    "Add attachment" : "Legg til vedlegg",
-    "Add from Files" : "Legg til fra filer",
+    "No messages in this folder!" : "Det er ingen meldinger i denne mappen!",
+    "Upload attachment" : "Last opp vedlegg",
+    "Add attachment from Files" : "Legg til vedlegg fra Filer",
     "Import into calendar" : "Importer til kalender",
     "Download attachment" : "Last ned vedlegg",
     "Save to Files" : "Lagre i Filer"
