@@ -2,11 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Poczta",
-    "Loading accounts …" : "Wczytywanie kont...",
+    "Loading accounts" : "Ładowanie kont",
     "Error while loading the accounts." : "Błąd podczas ładowania kont.",
     "Error while loading the selected account." : "Błąd podczas ładowania zaznaczonego konta.",
     "Can not load this folder." : "Nie można załadować tego folderu.",
-    "Loading {folder}" : "Wczytuję {folder}",
     "Searching for {query}" : "Wyszukiwanie {query}",
     "Error while deleting message." : "Błąd podczas usuwania wiadomości.",
     "Forwarded message" : "Wiadomość przekazana",
@@ -59,8 +58,8 @@ OC.L10N.register(
     "Junk" : "Spam",
     "All" : "Wszystkie",
     "Favorites" : "Ulubione",
-    "Creating account failed: " : "Utworzenie konta nie powiodło się:",
     "Auto detect failed. Please use manual mode." : "Autowykrywanie nie powiodło się. Proszę użyć trybu ręcznego.",
+    "Creating account failed: " : "Utworzenie konta nie powiodło się:",
     "Delete permanently" : "Trwale usuń",
     "& others" : "& inni",
     "Error loading message" : "Błąd podczas ładowania wiadomości",
@@ -118,8 +117,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane by chronić Twoją prywatność.",
     "Show images from this sender" : "Zobacz zdjęcia od tego nadawcy",
     "Forward" : "Prześlij dalej",
-    "Add attachment" : "Dodaj załącznik",
-    "Add from Files" : "Dodaj z plików",
+    "No messages in this folder!" : "Brak wiadomości w tym folderze!",
+    "Upload attachment" : "Dodaj załącznik",
+    "Add attachment from Files" : "Dodaj załącznik z Pliki",
     "Import into calendar" : "Importuj do kalendarza",
     "Download attachment" : "Pobierz załącznik",
     "Save to Files" : "Zapisz do plików"
