@@ -2,10 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Pošta",
+    "Loading accounts" : "Nahrávanie účtov",
     "Error while loading the accounts." : "Chyba pri načítaní účtov.",
     "Error while loading the selected account." : "Chyba počas načítania zvoleného účtu.",
     "Can not load this folder." : "Nie je možné načítať túto zložku.",
-    "Loading {folder}" : "Načítavam {folder}",
     "Searching for {query}" : "Vyhľadávam {query}",
     "Error while deleting message." : "Chyba pri mazaní správy.",
     "Forwarded message" : "Preposlané správy",
@@ -30,6 +30,8 @@ OC.L10N.register(
     "Unable to load the desired message" : "Požadovanú správu nie je možné načítať",
     "There was a problem loading the message" : "Nastal problém s načítaním správy",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová správa\nod {from}","%n nové správy\nod {from}","%n nových správ\nod {from}"],
+    "Nextcloud Mail" : "Nextcloud Mail",
     "Show all folders" : "Zobraziť všetky priečinky",
     "Collapse folders" : "Zvinúť priečinky",
     "Error while deleting account." : "Chyba pri mazaní účtu.",
@@ -47,6 +49,7 @@ OC.L10N.register(
     "Error while importing the calendar event" : "Nastala chyba pri importovaní udalosti kalendára",
     "Error while downloading calendar event" : "Nastala chyba pri sťahovaní udalosti kalendára",
     "Error while loading messages." : "Chyba počas načítavania správ.",
+    "Error while refreshing messages." : "Chyba počas obnovovania správ.",
     "Setting up your account" : "Nastavenie vášho účtu",
     "Inbox" : "Doručené",
     "Sent" : "Odoslané",
@@ -56,8 +59,8 @@ OC.L10N.register(
     "Junk" : "Spam",
     "All" : "Všetky",
     "Favorites" : "Obľúbené",
-    "Creating account failed: " : "Vytvorenie účtu zlyhalo:",
     "Auto detect failed. Please use manual mode." : "Automatická detekcia zlyhala. Prosím, použite manuálny režim.",
+    "Creating account failed: " : "Vytvorenie účtu zlyhalo:",
     "Delete permanently" : "Zmazať  natrvalo",
     "& others" : "& iné",
     "Error loading message" : "Chyba načítavania správy",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "Save" : "Uložiť",
     "Keyboard shortcuts" : "Klávesové skratky",
     "Speed up your Mail experience with these quick shortcuts." : "Zefektívnite svoju prácu s Mailom pomocou týchto rýchlych skratiek.",
+    "Compose new message" : "Nová správa",
     "Newer message" : "Novšia správa",
     "Older message" : "Staršia správa",
     "Toggle star" : "Prepnúť hviezdičku",
@@ -114,8 +118,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Obrázky boli zablokované pre ochranu Vášho súkromia.",
     "Show images from this sender" : "Zobraziť obrázky od tohoto odosielateľa",
     "Forward" : "Preposlať",
-    "Add attachment" : "Pridať prílohu",
-    "Add from Files" : "Pridať zo Súborov",
+    "No messages in this folder!" : "Žiadne správy v tomto priečinku!",
+    "Upload attachment" : "Nahrať prílohu",
+    "Add attachment from Files" : "Pridať prílohu zo Súborov",
     "Import into calendar" : "Importovať do kalendára",
     "Download attachment" : "Stiahnuť prílohu",
     "Save to Files" : "Uložiť do Súborov"
