@@ -25,7 +25,9 @@ OC.L10N.register(
     "Send message to {email}" : "送訊息給 {email}",
     "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "我們不能載入 {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "在載入 {tag}{name}{endtag}時出現問題",
     "We couldn’t load your message" : "我們無法載入您的訊息。",
+    "Unable to load the desired message" : "無法載入所需的訊息",
     "There was a problem loading the message" : "在載入信息時有些障礙",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n新訊息\n來自 {from}"],
@@ -34,15 +36,20 @@ OC.L10N.register(
     "Collapse folders" : "摺疊資料夾",
     "Error while deleting account." : "刪除帳號時發生錯誤",
     "Choose a file to add as attachment" : "選擇檔案作為附件",
+    "An error occurred while uploading {fname}" : "在上傳{fname}發生錯誤",
     "Reply" : "回覆",
     "Send" : "寄出",
     "Sending …" : "傳送中…",
     "Message sent!" : "訊息已寄出",
     "Server error" : "伺服器錯誤",
+    "An unknown error occurred" : "發生未知的錯誤",
     "Opening HTML drafts is not supported yet." : "目前尚未支援開啟 HTML 草稿",
     "Draft saved!" : "草稿已儲存！",
     "No writable calendars found" : "查無可寫入的日曆",
+    "Error while importing the calendar event" : "匯入日曆事件時發生錯誤",
+    "Error while downloading calendar event" : "下載日曆事件時發生錯誤",
     "Error while loading messages." : "載入訊息時發生錯誤",
+    "Error while refreshing messages." : "重新整理訊息時發生錯誤",
     "Setting up your account" : "完善你的帳戶",
     "Inbox" : "收件匣",
     "Sent" : "已送出",
