@@ -23,9 +23,11 @@
 namespace OCA\Mail\AppInfo;
 
 use OCA\Mail\Contracts\IAttachmentService;
+use OCA\Mail\Contracts\IAvatarService;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Service\Attachment\AttachmentService;
+use OCA\Mail\Service\AvatarService;
 use OCA\Mail\Service\MailManager;
 use OCA\Mail\Service\MailTransmission;
 use OCP\AppFramework\App;
@@ -45,6 +47,7 @@ class Application extends App {
 		$transport = $container->getServer()->getConfig()->getSystemValue('app.mail.transport', 'smtp');
 		$testSmtp = $transport === 'smtp';
 
+		$container->registerAlias(IAvatarService::class, AvatarService::class);
 		$container->registerAlias(IMailManager::class, MailManager::class);
 		$container->registerAlias(IAttachmentService::class, AttachmentService::class);
 		$container->registerAlias(IMailTransmission::class, MailTransmission::class);
@@ -57,6 +60,7 @@ class Application extends App {
 			$user = $container->query("UserId");
 			return $container->getServer()->getUserFolder($user);
 		});
+
 		$container->registerParameter("testSmtp", $testSmtp);
 		$container->registerParameter("referrer", isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : null);
 		$container->registerParameter("hostname", Util::getServerHostName());
