@@ -22,15 +22,9 @@
 namespace OCA\Mail\Service;
 
 use JsonSerializable;
-use OCA\Mail\Model\IMessage;
 
 interface IAccount extends JsonSerializable {
 
-	/**
-	 * @return array
-	 */
-	public function getConfiguration();
-
 	/**
 	 * @param $folderId
 	 * @return IMailbox
@@ -42,19 +36,6 @@ interface IAccount extends JsonSerializable {
 	 */
 	public function getEmail();
 
-	/**
-	 * @param IMessage $message
-	 * @param int|null $draftUID
-	 */
-	public function sendMessage(IMessage $message, $draftUID);
-
-	/**
-	 * @param IMessage $message
-	 * @param int|null $previousUID
-	 * @return int
-	 */
-	public function saveDraft(IMessage $message, $previousUID);
-
 	/**
 	 * @param string $folderId
 	 * @param int $messageId
@@ -62,10 +43,11 @@ interface IAccount extends JsonSerializable {
 	public function deleteMessage($folderId, $messageId);
 
 	/**
-	 * @param string[] $query
-	 * @return array
+	 * @param string $sourceFolderId
+	 * @param int $messageId
+	 * @param string $destFolderId
 	 */
-	public function getChangedMailboxes($query);
+	public function moveMessage($sourceFolderId, $messageId, $destFolderId);
 
 	/**
 	 * @return IMailBox
